@@ -33,7 +33,7 @@ class WarcioMiddleware:
         s3_dir = self.settings["S3DIR"] or ""
         import os
 
-        for root, dirs, files in os.walk(".", topdown=False):
+        for root, dirs, files in os.walk(job_dir, topdown=False):
             for name in files:
                 self.log.info(name)
                 if ".warc.gz" in name:
